/******************************************************************
 * CopyPolicy: GNU Public License 2 applies
 * 
 * cdda_paranoia generation III release 9.8
 * Copyright (C) 2001 Monty monty@xiph.org, xiphmont@mit.edu
 *
 ******************************************************************/


#define VERSION "cdparanoia III release 9.8 (March 23, 2001)\n"\
                "(C) 2001 Monty <monty@xiph.org> and Xiphophorus\n\n"\
		"Report bugs to paranoia@xiph.org\n"\
		"http://www.xiph.org/paranoia/\n"
